@@ -16,7 +16,6 @@ __author__ = "Guido van Rossum <guido@python.org>"
 __all__ = ["Driver", "load_grammar"]
 
 # Python imports
-import codecs
 import io
 import os
 import logging
@@ -95,11 +94,8 @@ class Driver(object):
 
     def parse_file(self, filename, encoding=None, debug=False):
         """Parse a file and return the syntax tree."""
-        stream = codecs.open(filename, "r", encoding)
-        try:
+        with io.open(filename, "r", encoding=encoding) as stream:
             return self.parse_stream(stream, debug)
-        finally:
-            stream.close()
 
     def parse_string(self, text, debug=False):
         """Parse a string and return the syntax tree."""
@@ -111,7 +107,7 @@ def _generate_pickle_name(gt):
     head, tail = os.path.splitext(gt)
     if tail == ".txt":
         tail = ""
-    sys_version_info = "3.6.15" + ".final.0"
+    sys_version_info = "3.8.19" + ".final.0"
     return head + tail + sys_version_info + ".pickle"
 
 
